/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "nsISupports.idl"
#include "nsISimpleEnumerator.idl"


/** 
 * An optional interface for accessing or removing the cookies
 * that are in the cookie list
 */

[scriptable, uuid(AAAB6710-0F2C-11d5-A53B-0010A401EB10)]
interface nsICookieManager : nsISupports
{

  /**
   * Called to remove all cookies from the cookie list
   */
  void removeAll();

  /**
   * Called to enumerate through each cookie in the cookie list.
   * The objects enumerated over are of type nsICookie
   */
  readonly attribute nsISimpleEnumerator enumerator;

  /**
   * Called to remove an individual cookie from the cookie list, specified
   * by host, name, and path. If the cookie cannot be found, no exception
   * is thrown. Typically, the arguments to this method will be obtained
   * directly from the desired nsICookie object.
   *
   * @param aHost The host or domain for which the cookie was set. @see
   *              nsICookieManager2::add for a description of acceptable host
   *              strings. If the target cookie is a domain cookie, a leading
   *              dot must be present.
   * @param aName The name specified in the cookie
   * @param aPath The path for which the cookie was set
   * @param aBlocked Indicates if cookies from this host should be permanently blocked
   *
   */
  void remove(in AUTF8String aHost,
              in ACString    aName,
              in AUTF8String aPath,
              in boolean     aBlocked);
};
